"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.MaterialTools = void 0;
var path = require("path");
var CSSBuilder_1 = require("./builders/CSSBuilder");
var Utils_1 = require("./common/Utils");
var DefaultConfig_1 = require("./common/DefaultConfig");
var MaterialBuilder_1 = require("./builders/MaterialBuilder");
var fse = require('fs-extra');
var buildCommandMap = {
    css: 'buildCSS',
    js: 'buildJS',
    theme: 'buildTheme',
    themes: 'buildTheme'
};
var MaterialTools = /** @class */ (function (_super) {
    __extends(MaterialTools, _super);
    function MaterialTools(_options) {
        var _this = this;
        if (!_options) {
            throw new Error('No options have been specified.');
        }
        var options = typeof _options === 'string' ? require(path.resolve(_options)) : _options;
        Utils_1.Utils.forEach(DefaultConfig_1.DefaultConfig.options, function (value, key) {
            if (typeof options[key] === 'undefined') {
                options[key] = value;
            }
        });
        if (options.destination) {
            options.destination = path.resolve(options.destination);
        }
        else {
            throw new Error('You have to specify a destination.');
        }
        // Initialize the MaterialBuilder with the validated options.
        _this = _super.call(this, options) || this;
        return _this;
    }
    /**
     * Builds all of the files or a subset of files.
     */
    MaterialTools.prototype.build = function () {
        var _this = this;
        var buildTypes = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            buildTypes[_i] = arguments[_i];
        }
        return this._getData().then(function (buildData) {
            var commands = buildTypes
                .filter(function (name) { return !!buildCommandMap[name]; })
                .map(function (key) { return _this[buildCommandMap[key]](buildData); });
            if (!commands.length) {
                Utils_1.Utils.forEach(buildCommandMap, function (methodName) { return commands.push(_this[methodName](buildData)); });
            }
            return Promise.all(commands).then(function () {
                if (buildData.files.license) {
                    // We don't have to wait for the license to be copied over.
                    _this._writeFile(path.join(_this._options.destination, 'LICENSE'), fse.readFileSync(buildData.files.license));
                }
                return buildData;
            });
        });
    };
    /**
     * Outputs the CSS, based on the options.
     * Returns a promise, which resolves at finish with the given destination paths.
     */
    MaterialTools.prototype.buildCSS = function (buildData) {
        var _this = this;
        return this._buildData(buildData)
            .then(function (data) { return _this._buildCSS(buildData); })
            .then(function (output) {
            var base = _this._outputBase;
            var license = output.license;
            // General standalone layout files directly from the module repository.
            var outputPromises = output.layoutFiles.map(function (layoutFile) {
                // Retrieve the last two extension name portions.
                var suffix = path.basename(layoutFile).split('.').slice(-2).join('.');
                var styles = CSSBuilder_1.CSSBuilder._loadStyles([layoutFile]);
                return _this._writeFile(base + "." + suffix, styles, output.license);
            }).concat([
                // Files with layout
                _this._writeFile(base + ".css", output.withLayout.source, license),
                _this._writeFile(base + ".min.css", output.withLayout.compressed, license),
                // Files without layout
                _this._writeFile(base + ".layout-none.css", output.withoutLayout.source, license),
                _this._writeFile(base + ".layout-none.min.css", output.withoutLayout.compressed, license)
            ]);
            return Promise.all(outputPromises);
        });
    };
    /**
     * Outputs the necessary JS, based on the options.
     * Returns a promise, which resolves at finish with the given destination paths.
     */
    MaterialTools.prototype.buildJS = function (buildData) {
        var _this = this;
        return this._buildData(buildData)
            .then(function (data) { return _this._buildJS(data); })
            .then(function (output) {
            return Promise.all([
                _this._writeFile(_this._outputBase + ".js", output.source, output.license),
                _this._writeFile(_this._outputBase + ".min.js", output.compressed, output.license),
                _this._writeFile(_this._outputBase + ".map", output.map)
            ]);
        });
    };
    /**
     * Outputs a static theme stylesheet, based on the specified options
     * Returns a promise, which resolves at finish with the given destination paths.
     */
    MaterialTools.prototype.buildTheme = function (buildData) {
        var _this = this;
        if (!this._options.theme && !this._options.themes) {
            return;
        }
        return this._buildData(buildData)
            .then(function (data) { return _this._buildTheme(data); })
            .then(function (output) {
            return Promise.all([
                _this._writeFile(_this._outputBase + ".themes.min.css", output.compressed, output.license),
                _this._writeFile(_this._outputBase + ".themes.css", output.source, output.license)
            ]);
        });
    };
    /** Transforms a specified build data into a promise and loads the data if not present. */
    MaterialTools.prototype._buildData = function (buildData) {
        return buildData ? Promise.resolve(buildData) : this._getData();
    };
    /** Writes a given content with the associated license to a new file */
    MaterialTools.prototype._writeFile = function (destination, content, license) {
        if (license === void 0) { license = ''; }
        return new Promise(function (resolve, reject) {
            fse.mkdirp(path.dirname(destination), function (error) {
                if (error) {
                    reject(error);
                }
                else {
                    fse.writeFileSync(destination, license + content);
                    resolve(destination);
                }
            });
        });
    };
    return MaterialTools;
}(MaterialBuilder_1.MaterialBuilder));
exports.MaterialTools = MaterialTools;
//# sourceMappingURL=MaterialTools.js.map