"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JSBuilder = void 0;
var fse = require('fs-extra');
var uglify = require('uglify-js');
var JSBuilder = /** @class */ (function () {
    function JSBuilder() {
    }
    /**
     * Generates the minified and non-minified JS, as well as a source map, based on the options.
     */
    JSBuilder.build = function (data, filename) {
        var mainModule = this._buildMainModule(data.dependencies._mainModule);
        var raw = data.files.js.map(function (path) { return fse.readFileSync(path).toString(); }).join('\n');
        var source = [mainModule, '', raw].join('\n');
        var compressed = uglify.minify(source, {
            fromString: true,
            outSourceMap: filename,
            // Suppress "WARN: Output exceeds 32000 characters" warnings from UglifyJS 2.x
            // Those warnings can be safely ignored and shouldn't show up in the CLI.
            output: { 'max_line_len': Number.MAX_VALUE }
        });
        return {
            source: source,
            compressed: compressed.code,
            map: compressed.map,
            license: data.license
        };
    };
    /**
     * Builds a javascript snippet, which registers a new AngularJS Module with
     * the required dependencies.
     */
    JSBuilder._buildMainModule = function (mainModule) {
        var dependencyString = mainModule.dependencies.map(function (name) { return "'" + name + "'"; }).join(', ');
        return [
            '(function() {',
            '  "use strict";',
            "  angular.module('" + mainModule.rawName + "', [" + dependencyString + "]);",
            '})();'
        ].join('\n');
    };
    return JSBuilder;
}());
exports.JSBuilder = JSBuilder;
//# sourceMappingURL=JSBuilder.js.map