"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Utils = void 0;
/** RegEx to retrieve the digits of a ngMaterial version. */
var VERSION_DIGIT_REGEX = /([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})(?:-rc(?:.|-)([0-9]{1,3}))?/;
var DASH_TO_CAMEL_REGEX = /\W+(.)/g;
/**
 * Common utility functions for the Material Tools.
 */
var Utils = /** @class */ (function () {
    function Utils() {
    }
    /**
     * Generates a unique identifier / number for the specified version.
     * Those numbers can be easily compared. The higher number is the newer version.
     * Returns `-1`, when the version couldn't be correctly parsed.
     */
    Utils.extractVersionNumber = function (version) {
        var matches = version.match(VERSION_DIGIT_REGEX);
        if (!matches) {
            return -1;
        }
        matches = matches
            .slice(1)
            .map(function (digit) { return fillDigit(digit, 3); });
        function fillDigit(digitString, maxSlotLength) {
            if (digitString === void 0) { digitString = '999'; }
            var digitLength = digitString.length;
            for (var i = 0; i < maxSlotLength - digitLength; i++) {
                digitString = "0" + digitString;
            }
            return digitString;
        }
        return parseInt(matches.join(''));
    };
    /**
     * Iterates through an object variable and calls the specified iterator function
     * with the given value and key.
     * Returning a value of the iteration function will overwrite the current item.
     */
    Utils.forEach = function (object, fn) {
        for (var _key in object) {
            if (object.hasOwnProperty(_key)) {
                fn(object[_key], _key);
            }
        }
    };
    /**
     * Converts a dash-cased string to camelCase.
     */
    Utils.dashToCamel = function (str) {
        return str.replace(DASH_TO_CAMEL_REGEX, function (x, chr) {
            return chr.toUpperCase();
        });
    };
    return Utils;
}());
exports.Utils = Utils;
//# sourceMappingURL=Utils.js.map