"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VersionDownloader = void 0;
var zlib = require("zlib");
var Logger_1 = require("./Logger");
var request = require('request');
var tar = require('tar-fs');
var MODULE_REPO = 'https://github.com/angular/bower-material/archive/v';
var SOURCE_REPO = 'https://github.com/angular/material/archive/v';
var EXTENSION = '.tar.gz';
var VersionDownloader = /** @class */ (function () {
    function VersionDownloader() {
    }
    VersionDownloader._downloadFile = function (url, destination) {
        Logger_1.Logger.info("Downloading " + url + ".");
        return new Promise(function (resolve, reject) {
            var stream = request(url)
                .on('error', reject)
                .on('response', function (response) {
                if (response.statusCode === 200) {
                    stream
                        .pipe(zlib.createGunzip())
                        .pipe(tar.extract(destination, {
                        map: function (header) {
                            header.name = header.name.substring(header.name.indexOf('/'));
                            return header;
                        }
                    }))
                        .on('finish', function () {
                        resolve(destination);
                        stream.destroy();
                        Logger_1.Logger.info("Downloaded " + url + " successfully.");
                    });
                }
                else {
                    reject("Failed to download " + url + ". Status code: " + response.statusCode + ".");
                    stream.destroy();
                }
            });
        });
    };
    /**
     * Fetches the specified version from the Bower Material Repository and stores
     * it in the specified destination.
     * @returns {Promise.<String>} Path of the downloaded Bower Material version.
     */
    VersionDownloader.getModuleVersion = function (version, destination) {
        return this._downloadFile(MODULE_REPO + version + EXTENSION, destination);
    };
    /**
     * Fetches the specified version from the AngularJS Material Repository and
     * stores it in the specified destination.
     * @returns {Promise.<String>} Path of the downloaded AngularJS Material version.
     */
    VersionDownloader.getSourceVersion = function (version, destination) {
        return this._downloadFile(SOURCE_REPO + version + EXTENSION, destination);
    };
    return VersionDownloader;
}());
exports.VersionDownloader = VersionDownloader;
//# sourceMappingURL=VersionDownloader.js.map