"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DependencyResolver = void 0;
var Logger_1 = require("../common/Logger");
var VirtualContext_1 = require("../virtual_context/VirtualContext");
var DependencyResolver = /** @class */ (function () {
    function DependencyResolver() {
    }
    /**
     * Determines the dependencies and parent dependencies of the specified
     * AngularJS `modules` within a `file`.
     */
    DependencyResolver.resolve = function (file, modules, mainModule) {
        // Create a virtual context, to isolate the script which modifies the globals
        // to be able to mock a Browser Environment.
        var virtualContext = new VirtualContext_1.VirtualContext({
            $$moduleName: file,
            $$mainModule: mainModule
        });
        // Execute our dependency resolve script in the virtual context, to completely
        // isolate the window modification from our node environment.
        var output = virtualContext.run(__dirname + "/isolated_angular.js", {
            strictMode: true
        });
        var targetModules = modules && modules.length ? modules : Object.keys(output.dependencies);
        var resultMap = {
            _flat: [],
            _mainModule: output.mainModule
        };
        targetModules.forEach(function addDependencies(componentName) {
            var exists = output.dependencies.hasOwnProperty(componentName);
            if (exists && !resultMap.hasOwnProperty(componentName)) {
                var component = output.dependencies[componentName];
                var dependencies = component.dependencies;
                resultMap[componentName] = dependencies;
                resultMap._flat.push(componentName);
                if (resultMap._mainModule.dependencies.indexOf(component.rawName) === -1) {
                    resultMap._mainModule.dependencies.push(component.rawName);
                }
                if (dependencies && dependencies.length) {
                    dependencies.forEach(addDependencies);
                }
            }
            else if (!exists) {
                Logger_1.Logger.warn("Module \"" + componentName + "\" does not exist and will be skipped.");
            }
        });
        return resultMap;
    };
    return DependencyResolver;
}());
exports.DependencyResolver = DependencyResolver;
//# sourceMappingURL=DependencyResolver.js.map