"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalResolver = void 0;
var path = require("path");
var glob = require('glob');
var LocalResolver = /** @class */ (function () {
    function LocalResolver() {
    }
    /**
     * Looks up files that match a glob pattern.
     * When marking as required and no files could be found, the Promise will be rejected.
     */
    LocalResolver.resolvePattern = function (pattern, dir, required) {
        if (required === void 0) { required = true; }
        return new Promise(function (resolve, reject) {
            glob(pattern, { root: dir, nocase: true }, function (error, files) {
                if (error || (required && (!files || !files.length))) {
                    reject(error || "Could not find files matching " + glob + " in " + dir + ".");
                }
                else {
                    resolve(files);
                }
            });
        });
    };
    /**
     * Looks up files, with a given extension, in the file system.
     * Excludes minified files and themes.
     */
    LocalResolver.resolveExtension = function (modules, extname) {
        var _a;
        var rest = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            rest[_i - 2] = arguments[_i];
        }
        var pattern = "/*(" + modules.join('|') + ")/**/!(*.min|*-theme)." + extname;
        return (_a = this.resolvePattern).call.apply(_a, __spreadArrays([this, pattern], rest));
    };
    /**
     * Looks up the theme files for an array of modules.
     * Returns a promise which resolves with an array of the required theme files.
     */
    LocalResolver.resolveThemes = function (modules) {
        var _a;
        var rest = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            rest[_i - 1] = arguments[_i];
        }
        var pattern = "/*(" + modules.join('|') + ")/**/*-theme.+(scss|css)";
        return (_a = this.resolvePattern).call.apply(_a, __spreadArrays([this, pattern], rest, [false]));
    };
    /**
     * Looks up for all SCSS files, related to the specified modules.
     * Returns a promise which resolves with an array of the required SCSS files.
     */
    LocalResolver.resolveSCSS = function (modules, sourceDirectory) {
        return Promise.all([
            this.resolveExtension(modules, 'scss', path.join(sourceDirectory, 'components'), false),
            this.resolvePattern('/*.scss', path.join(sourceDirectory, 'core', 'style'), false)
        ]).then(function (data) {
            return data[0].concat(data[1]);
        });
    };
    /**
     * Resolves JS and CSS files within a directory.
     * Returns a promise which fulfills with the resolved files for the modules.
     */
    LocalResolver.resolve = function (modules, _package) {
        var moduleDirectory = path.join(_package.module, 'modules');
        var jsModules = path.join(moduleDirectory, 'js');
        var sourceRoot = path.join(_package.source, 'src');
        var sourceComponents = path.join(sourceRoot, 'components');
        var layoutModules = path.join(moduleDirectory, 'layouts');
        return Promise.all([
            this.resolveExtension(modules, 'js', jsModules),
            this.resolveExtension(modules, 'css', jsModules, false),
            this.resolveThemes(modules, sourceComponents),
            this.resolveThemes(modules, sourceRoot),
            this.resolvePattern('/*.+(layouts|layout-attributes).css', layoutModules, false),
            this.resolveSCSS(modules, sourceRoot),
            this.resolvePattern('/LICENSE', _package.module, false)
        ])
            .then(function (results) {
            return {
                root: _package.root,
                js: results[0],
                css: results[1],
                themes: results[2].concat(results[3]),
                layout: results[4],
                scss: results[5],
                license: results[6][0]
            };
        });
    };
    return LocalResolver;
}());
exports.LocalResolver = LocalResolver;
//# sourceMappingURL=LocalResolver.js.map