"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VirtualContext = void 0;
var MockBrowser_1 = require("./MockBrowser");
var Utils_1 = require("../common/Utils");
var SandboxRequire_1 = require("./SandboxRequire");
var VirtualContext = /** @class */ (function () {
    /**
     * Creates a virtual context, which allows developers to run files inside of a new V8
     * JavaScript Instance.
     * The virtual context includes a sandboxed NodeJS environment inside of the V8 machine.
     */
    function VirtualContext(globals) {
        var _this = this;
        this.globals = new MockBrowser_1.BrowserWindow();
        // Apply the custom globals from the developer to the default globals
        // without modifying the globals reference, because otherwise we would
        // lose the circular references.
        Utils_1.Utils.forEach(globals, function (value, key) { return _this.globals[key] = value; });
    }
    /**
     * Runs the specified file inside of the Virtual Context and returns the synchronized
     * module exports from the second V8 instance.
     */
    VirtualContext.prototype.run = function (fileName, options) {
        return SandboxRequire_1.createSandboxRequire(__filename, this.globals, options)(fileName);
    };
    return VirtualContext;
}());
exports.VirtualContext = VirtualContext;
//# sourceMappingURL=VirtualContext.js.map